Documentation
¶
Overview ¶
Package closeutil provides convenience methods to wrap closing process with logging on suppression of related errors
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CloseOrLog ¶
CloseOrLog is an util function that calls io.Closer.Close method on provided closer and logs the error with provided logger if Close fails.
func CloseOrSuppress ¶
CloseOrSuppress is an util function that calls io.Closer.Close method on provided closer and ignores the output.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.