holder

package
v1.0.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 15, 2026 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Overview

Package holder provides several ways of storing the value in a reactive-ish way, so the caller may be able to read fresh current value every time

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Holder

type Holder[T any] interface {
	Get() T
}

func ConstHolder

func ConstHolder[T any](value T) Holder[T]

func FuncHolder

func FuncHolder[T any](f func() T) Holder[T]

func RefHolder

func RefHolder[T any](ref *T) Holder[T]

Jump to