ref

package
v1.0.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 15, 2026 License: Apache-2.0 Imports: 0 Imported by: 0

Documentation

Overview

Package ref provides utils for interacting with reference values, for example taking the ref of immediate value or safely casting ref to default value of type

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Take

func Take[T any](value T) *T

func Unwrap

func Unwrap[T any](value *T) T

Types

This section is empty.

Jump to