package
Version:
v1.0.7
Opens a new window with list of versions in this module.
Published: Mar 15, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package holder provides several ways of storing the value in a
reactive-ish way, so the caller may be able to read fresh current value every time
type Holder[T any] interface {
Get() T
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.