Discover Packages
github.com/holyheld/gointernals
ref
package
Version:
v1.0.7
Opens a new window with list of versions in this module.
Published: Mar 15, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
Package ref provides utils for interacting with reference values, for example
taking the ref of immediate value or safely casting ref to default value of type
func Take[T any ](value T) *T
func Unwrap[T any ](value *T) T
Source Files
¶
Click to show internal directories.
Click to hide internal directories.